/* ----------------------------------------------------------------------- */
/* Script, ou programme, Stata illustrant l'Exercice 2 de la section Polys */
/* ----------------------------------------------------------------------- */

/* lecture des donnes, prciser le chemin ou dfinir le rpertoire si ncessaire */
use "aviation.dta", clear

/* quelques statistiques descriptives */
summarize
table pp

/* cration de nouvelles variables (production par input) */
/* gener ou gen */
gen qsl = q/l
gen qsk = q/k

/* statistiques par groupe */
by pp, sort : summarize qsl qsk

/* test de Student d'galit des moyennes pour qsl en supposant les variances gales */
ttest qsl, by(pp)

/* le mme en supposant les variances ingales */
ttest qsl, by(pp) unequal

/* cration des nouvelles variables pour traiter par les mco le modle linaris */
gen lq=ln(q)
gen ll=ln(l)
gen lk=ln(k)

/* des graphiques "x y" */
twoway (scatter lq ll)
twoway (scatter lq lk)

/* les corrlations */
/* correlate ou corr */
corr lq ll lk

/* une rgression simple */
/* regress ou reg */
reg lq lk

/* valeur ajuste de la variable  expliquer (en utilisant la dernire rgression opre) */
predict lqp

/* graphique avec la droite d'ajustement */
twoway (scatter lq lk) (line lqp lk)

/* variante */
twoway (scatter lq lk) (lfit lq lk)

/* estimation du modle de base */
reg lq ll lk

/* test intgr de Fisher d'une hypothse linaire (ici l'absence de rendement d'chelle) */
test ll+lk=1

/* pour se souvenir de tous les rsultats disponibles aprs une rgression */
ereturn list

/* pour archiver la somme des carrs des rsidus, qui servira plus tard */
/* scalar ou scal */
scal scr0=e(rss)

/* pour voir et vrifier */
/* display ou disp */
disp(scr0)

/* estimation du modle contraint (pas indispensable, juste pour voir la procdure) */
constraint define 1 ll+lk=1
cnsreg lq ll lk, constraints(1)

/* cration des variables pour estimer le modle transform */
gen lql=lq-ll
gen lkl=lk-ll

/* estimation du modle transform */
reg lql ll lkl

/* cration de la dummy variable notant le caractre "public" d'une compagnie */
gen dpub=(pp=="publique")

/* une petite vrification */
list pp dpub

/* estimation du modle avec la dummy variable */
reg lq ll lk dpub

/* variante avec cration automatique de la dummy variable via la commande xi */
xi : reg lq ll lk i.pp

/* rgressions spares avec archivage de la somme des carrs des rsidus */
reg lq ll lk if dpub==1
scal scr1=e(rss)
reg lq ll lk if dpub==0
scal scr2=e(rss)

/* calcul de la quantit permettant le test de Chow */
disp(scr0)
disp(scr1)
disp(scr2)
scal chow=((scr0-(scr1+scr2))/3)/((scr1+scr2)/44)
disp(chow)

/* test de Chow  l'aide de la distribution de Fisher approprie */
disp(Ftail(3,44,chow))


